# Cal Calculator project

This tiny project is to construct a calculator based on eval() and Wolfram Alpha. Some simple expressions will be directly evaluated by eval(), while more complicated expressions can be calculated via Wolfram Alpha, including but not limited to integration, scientific constant and etc.